LastResponse

Enum LastResponse 

pub enum LastResponse {
    NoResponse,
    RespRst,
    RespCon(bool),
    RespNon,
}
Distinguishes different cases on how we can respond to a request

Variants



NoResponse

We have not yet answered any request



RespRst

The last request was answered with a RST message



RespCon(bool)

The last request was answered with a CON message

The contained bool stores if the CON message was successfully acked. If false, transmitting the CON timed out.



RespNon

The last request was answered with a separate NON response or a piggybacked response (in both cases, we do not know if the requester has received our response)