Module options

Module options 

CoAP Options

This module handles the construction and parsing of CoAP Options. Refer to https://www.rfc-editor.org/rfc/rfc7252#section-5.4 and https://www.rfc-editor.org/rfc/rfc7252#section-5.10 for further information.

Structs

CoapOption
A decoded CoAP Option
OptionIterator
An Iterator over all options in a message

Enums

CoapOptionName
Available CoAP Option types (refer to the RFCs for more information):
Error
Error Type for parsing Options

Functions

encode_to_buf
Encodes a slice of CoapOptions into a buffer and returns the encoded length
sort_options_vec
Helper function to (stable) sort a Vec<CoapOption>.