CoAP Options
This module handles the construction and parsing of CoAP Options. Refer to https://www.rfc-editor.org/rfc/rfc7252#section-5.4 and https://www.rfc-editor.org/rfc/rfc7252#section-5.10 for further information.
Structs
- Coap
Option - A decoded CoAP Option
- Option
Iterator - An Iterator over all options in a message
Enums
- Coap
Option Name - Available CoAP Option types (refer to the RFCs for more information):
- Error
- Error Type for parsing Options
Functions
- encode_
to_ buf - Encodes a slice of
CoapOptions into a buffer and returns the encoded length - sort_
options_ vec - Helper function to (stable) sort a
Vec<CoapOption>.